=====
scipr
=====

.. image:: https://img.shields.io/pypi/v/scipr.svg
        :target: https://pypi.python.org/pypi/scipr

.. image:: https://img.shields.io/travis/amiralavi/scipr.svg
        :target: https://travis-ci.org/amiralavi/scipr

.. image:: https://readthedocs.org/projects/scipr/badge/?version=latest
        :target: https://scipr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

Single Cell Iterative Point set Registration (SCIPR)


* Free software: BSD license
* Homepage & Documentation: https://scipr.readthedocs.io.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
